==> allegro-devel-5.0.9_2.txz: usr/local/share/examples/allegro-devel/CMakeFiles/ex_font_justify.dir/DependInfo.cmake <==
# The set of languages for which implicit dependencies are needed:
set(CMAKE_DEPENDS_LANGUAGES
  "CXX"
  )
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_CXX
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/examples/ex_font_justify.cpp" "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/examples/CMakeFiles/ex_font_justify.dir/ex_font_justify.cpp.o"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/examples/nihgui.cpp" "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/examples/CMakeFiles/ex_font_justify.dir/nihgui.cpp.o"
  )
set(CMAKE_CXX_COMPILER_ID "GNU")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS
  "ALLEGRO_POPUP_EXAMPLES"
  )

# Targets to which this target links.
set(CMAKE_TARGET_LINKED_INFO_FILES
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/addons/font/CMakeFiles/allegro_font.dir/DependInfo.cmake"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/addons/primitives/CMakeFiles/allegro_primitives.dir/DependInfo.cmake"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/addons/image/CMakeFiles/allegro_image.dir/DependInfo.cmake"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/addons/ttf/CMakeFiles/allegro_ttf.dir/DependInfo.cmake"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/CMakeFiles/allegro.dir/DependInfo.cmake"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/addons/main/CMakeFiles/allegro_main.dir/DependInfo.cmake"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/addons/native_dialog/CMakeFiles/allegro_dialog.dir/DependInfo.cmake"
  )

# The include file search paths:
set(CMAKE_C_TARGET_INCLUDE_PATH
  "include"
  "examples/../addons/acodec"
  "examples/../addons/audio"
  "examples/../addons/color"
  "examples/../addons/font"
  "examples/../addons/image"
  "examples/../addons/main"
  "examples/../addons/memfile"
  "examples/../addons/native_dialog"
  "examples/../addons/physfs"
  "examples/../addons/primitives"
  "examples/../addons/ttf"
  "/usr/local/include"
  )
set(CMAKE_CXX_TARGET_INCLUDE_PATH ${CMAKE_C_TARGET_INCLUDE_PATH})
set(CMAKE_Fortran_TARGET_INCLUDE_PATH ${CMAKE_C_TARGET_INCLUDE_PATH})
set(CMAKE_ASM_TARGET_INCLUDE_PATH ${CMAKE_C_TARGET_INCLUDE_PATH})

==> allegro-devel-5.0.9_4.txz: usr/local/share/examples/allegro-devel/CMakeFiles/ex_font_justify.dir/DependInfo.cmake <==
# The set of languages for which implicit dependencies are needed:
set(CMAKE_DEPENDS_LANGUAGES
  "CXX"
  )
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_CXX
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/examples/ex_font_justify.cpp" "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/examples/CMakeFiles/ex_font_justify.dir/ex_font_justify.cpp.o"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/examples/nihgui.cpp" "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/examples/CMakeFiles/ex_font_justify.dir/nihgui.cpp.o"
  )
set(CMAKE_CXX_COMPILER_ID "GNU")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_CXX
  "ALLEGRO_POPUP_EXAMPLES"
  )

# The include file search paths:
set(CMAKE_CXX_TARGET_INCLUDE_PATH
  "include"
  "examples/../addons/acodec"
  "examples/../addons/audio"
  "examples/../addons/color"
  "examples/../addons/font"
  "examples/../addons/image"
  "examples/../addons/main"
  "examples/../addons/memfile"
  "examples/../addons/native_dialog"
  "examples/../addons/physfs"
  "examples/../addons/primitives"
  "examples/../addons/ttf"
  "/usr/local/include"
  )

# Targets to which this target links.
set(CMAKE_TARGET_LINKED_INFO_FILES
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/addons/primitives/CMakeFiles/allegro_primitives.dir/DependInfo.cmake"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/addons/image/CMakeFiles/allegro_image.dir/DependInfo.cmake"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/addons/ttf/CMakeFiles/allegro_ttf.dir/DependInfo.cmake"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/addons/main/CMakeFiles/allegro_main.dir/DependInfo.cmake"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/addons/native_dialog/CMakeFiles/allegro_dialog.dir/DependInfo.cmake"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/addons/font/CMakeFiles/allegro_font.dir/DependInfo.cmake"
  "/wrkdirs/usr/ports/devel/allegro-devel/work/allegro-5.0.9/CMakeFiles/allegro.dir/DependInfo.cmake"
  )

# Fortran module output directory.
set(CMAKE_Fortran_TARGET_MODULE_DIR "")
